@@ -8,7 +8,8 @@ CONTEXT_SETTINGS = dict(
     help_option_names=[
         '-h',
         '--help'
-    ]
+    ],
+    auto_envvar_prefix='VBIMAGETOTEXT',
 )
 
 
